@@ -11,6 +11,7 @@ within a Python package.
 """
 from collections import defaultdict
 from os.path import join as pjoin
+from pathlib import Path
 import io
 import os
 import functools
@@ -28,9 +29,9 @@ if os.path.exists('MANIFEST'): os.remove('MANIFEST')
 
 from setuptools import Command
 from setuptools.command.build_py import build_py
-from setuptools.command.sdist import sdist
 
 # Note: distutils must be imported after setuptools
+from distutils.command.sdist import sdist
 from distutils import log
 
 from setuptools.command.develop import develop
@@ -48,7 +49,7 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.7.1'
+__version__ = '0.7.6'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
@@ -401,6 +402,29 @@ def ensure_targets(targets):
     return TargetsCheck
 
 
+def skip_if_exists(paths, CommandClass):
+    """Skip a command if list of paths exists."""
+    def should_skip():
+        return any(not Path(path).exist() for path in paths)
+    class SkipIfExistCommand(Command):
+        def initialize_options(self):
+            if not should_skip:
+                self.command = CommandClass(self.distribution)
+                self.command.initialize_options()
+            else:
+                self.command = None
+
+        def finalize_options(self):
+            if self.command is not None:
+                self.command.finalize_options()
+
+        def run(self):
+            if self.command is not None:
+                self.command.run()
+
+    return SkipIfExistCommand
+
+
 # `shutils.which` function copied verbatim from the Python-3.3 source.
 def which(cmd, mode=os.F_OK | os.X_OK, path=None):
     """Given a command, mode, and a PATH string, return the path which
@@ -516,12 +540,14 @@ def _get_develop_handler():
     class _develop(develop):
 
         def install_for_development(self):
+            self.finalize_options()
             super(_develop, self).install_for_development()
             self.run_command('handle_files')
+            prefix = self.install_base or self.prefix or sys.prefix
             for target_dir, filepaths in self.distribution.data_files:
                 for filepath in filepaths:
                     filename = os.path.basename(filepath)
-                    target = os.path.join(sys.prefix, target_dir, filename)
+                    target = os.path.join(prefix, target_dir, filename)
                     self.mkpath(os.path.dirname(target))
                     outf, copied = self.copy_file(filepath, target)
 
